==> spip_3.2.11.orig.tar.xz: plugins-dist/medias/lang/medias_cpf_hat.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=cpf_hat
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_ajouter_document' => 'AJOUTE YON DOKIMAN', # MODIF
	'bouton_ajouter_image' => 'AJOUTE YON IMAJ', # MODIF

	// D
	'double_clic_inserer_doc' => 'Apiyé-doub pou mèt tichemen-nan nan teks sa-a',

	// E
	'entree_dimensions' => 'Tay :',
	'entree_titre_document' => 'Kouman dokiman i rele :',
	'entree_titre_image' => 'Kouman imaj i rele :',

	// I
	'image_tourner_180' => 'Touné 180°',
	'image_tourner_droite' => 'Touné 90° drwat ',
	'image_tourner_gauche' => 'Touné 90° gòch',
	'info_document' => 'Dokiman',
	'info_documents' => 'Dokiman yo',
	'info_inclusion_directe' => 'Enklizyon dirèk :',
	'info_inclusion_vignette' => 'Enklizyon viyèt sa-a :',
	'info_installer_tous_documents' => 'Enstal tout dokiman',
	'info_logo_max_taille' => 'Fok logo yo se mwen @maxi@ (fichye sa-a se @actuel@).',
	'info_portfolio' => 'Pòtfolio',
	'info_referencer_doc_distant' => 'Réféwanse yon dokiman-déo sou entènèt :',
	'info_telecharger' => 'Telechaj sou lòdinatè ou :',

	// T
	'texte_documents_joints' => 'Ou kapab permè ajoute tou dokiman (fichye birotik, limaj,
 miltimédia, etousa.) nan atik ak ribrik yo. Fichye sa-yo
 se posib référans azot aprè nan latik
 osnon afiche azot tou sèl.', # MODIF
	'texte_documents_joints_2' => 'Règlaj-la ka pa enpeche bay zot limaj nan atik dirékman.', # MODIF
	'titre_documents_joints' => 'Dokiman yo te jwenn nan atik',
	'tout_dossier_upload' => 'Dosyé-a tout antyé @upload@',

	// U
	'upload_fichier_zip' => 'Fichye ZIP',
	'upload_fichier_zip_texte' => 'Fichye sak w ap pwopoze instale se yon fichye Zip.',
	'upload_fichier_zip_texte2' => 'Fichye se petèt :',
	'upload_limit' => 'Fichye a se two gwo pou servèr la ; pli gran tay posib pou <i>upload</i>se @max@.',
	'upload_zip_decompacter' => 'dekonprese ek chak eleman li ka kontni se instale sou sit-la. Fichye yo ke instale sou sit-la se :',
	'upload_zip_telquel' => 'te enstale komsa kom achiv koprese Zip ;'
);

==> spip_4.4.5+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_cpf_hat.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=cpf_hat
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'AJOUTE YON DOKIMAN', # MODIF
	'bouton_ajouter_image' => 'AJOUTE YON IMAJ', # MODIF

	// D
	'double_clic_inserer_doc' => 'Apiyé-doub pou mèt tichemen-nan nan teks sa-a',

	// E
	'entree_dimensions' => 'Tay :',
	'entree_titre_document' => 'Kouman dokiman i rele :',
	'entree_titre_image' => 'Kouman imaj i rele :',

	// I
	'image_tourner_180' => 'Touné 180°',
	'image_tourner_droite' => 'Touné 90° drwat ',
	'image_tourner_gauche' => 'Touné 90° gòch',
	'info_document' => 'Dokiman',
	'info_documents' => 'Dokiman yo',
	'info_inclusion_directe' => 'Enklizyon dirèk :',
	'info_inclusion_vignette' => 'Enklizyon viyèt sa-a :',
	'info_installer_tous_documents' => 'Enstal tout dokiman',
	'info_logo_max_taille' => 'Fok logo yo se mwen @maxi@ (fichye sa-a se @actuel@).',
	'info_portfolio' => 'Pòtfolio',
	'info_referencer_doc_distant' => 'Réféwanse yon dokiman-déo sou entènèt :',
	'info_telecharger' => 'Telechaj sou lòdinatè ou :',

	// T
	'texte_documents_joints' => 'Ou kapab permè ajoute tou dokiman (fichye birotik, limaj,
 miltimédia, etousa.) nan atik ak ribrik yo. Fichye sa-yo
 se posib référans azot aprè nan latik
 osnon afiche azot tou sèl.', # MODIF
	'texte_documents_joints_2' => 'Règlaj-la ka pa enpeche bay zot limaj nan atik dirékman.', # MODIF
	'titre_documents_joints' => 'Dokiman yo te jwenn nan atik',
	'tout_dossier_upload' => 'Dosyé-a tout antyé @upload@',

	// U
	'upload_fichier_zip' => 'Fichye ZIP',
	'upload_fichier_zip_texte' => 'Fichye sak w ap pwopoze instale se yon fichye Zip.',
	'upload_fichier_zip_texte2' => 'Fichye se petèt :',
	'upload_limit' => 'Fichye a se two gwo pou servèr la ; pli gran tay posib pou <i>upload</i>se @max@.',
	'upload_zip_decompacter' => 'dekonprese ek chak eleman li ka kontni se instale sou sit-la. Fichye yo ke instale sou sit-la se :',
	'upload_zip_telquel' => 'te enstale komsa kom achiv koprese Zip ;',
];
